@@ -4,6 +4,6 @@
 # Declaration of tests for the pcollections package.
 # By Noah C. Benson
 
-from ._list import TestPList
+from ._list import (TestPList, TestLList)
 from ._set import TestPSet
-from ._dict import TestPDict
+from ._dict import (TestPDict, TestLDict)
